# Wizard
Custom audio stream using text to speech and central server to help with memorizing quotes. Dedicated to Booker T. Washington, the Wizard of Tuskegee. 

# Usage
- To create source distribution: `python setup.py sdist`
- To upload to PyPi: `twine upload dist/*`
- To install locally: `pip3 install --editable .`